"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .inputaudio import InputAudio, InputAudioTypedDict
from opperai.types import BaseModel
from opperai.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal
from typing_extensions import Annotated, TypedDict


class ChatCompletionContentPartInputAudioParamTypedDict(TypedDict):
    input_audio: InputAudioTypedDict
    type: Literal["input_audio"]


class ChatCompletionContentPartInputAudioParam(BaseModel):
    input_audio: InputAudio

    TYPE: Annotated[
        Annotated[
            Literal["input_audio"], AfterValidator(validate_const("input_audio"))
        ],
        pydantic.Field(alias="type"),
    ] = "input_audio"
