"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .examplein import ExampleIn, ExampleInTypedDict
from opperai.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Any, Dict, List
from typing_extensions import NotRequired, TypedDict


class AppAPIPublicV2FunctionsCallFunctionRequestTypedDict(TypedDict):
    input: NotRequired[Nullable[Any]]
    r"""Input to the function"""
    parent_span_id: NotRequired[Nullable[str]]
    examples: NotRequired[Nullable[List[ExampleInTypedDict]]]
    tags: NotRequired[Nullable[Dict[str, str]]]
    r"""Tags to add to the call event"""


class AppAPIPublicV2FunctionsCallFunctionRequest(BaseModel):
    input: OptionalNullable[Any] = UNSET
    r"""Input to the function"""

    parent_span_id: OptionalNullable[str] = UNSET

    examples: OptionalNullable[List[ExampleIn]] = UNSET

    tags: OptionalNullable[Dict[str, str]] = UNSET
    r"""Tags to add to the call event"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["input", "parent_span_id", "examples", "tags"]
        nullable_fields = ["input", "parent_span_id", "examples", "tags"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
