"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .listfunctionsresponseitem import (
    ListFunctionsResponseItem,
    ListFunctionsResponseItemTypedDict,
)
from .meta import Meta, MetaTypedDict
from opperai.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class PaginatedResponseListFunctionsResponseItemTypedDict(TypedDict):
    meta: MetaTypedDict
    data: List[ListFunctionsResponseItemTypedDict]
    r"""List of items returned in the response"""


class PaginatedResponseListFunctionsResponseItem(BaseModel):
    meta: Meta

    data: List[ListFunctionsResponseItem]
    r"""List of items returned in the response"""
