"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .updatespanmetricrequest import (
    UpdateSpanMetricRequest,
    UpdateSpanMetricRequestTypedDict,
)
from opperai.types import BaseModel
from opperai.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class UpdateMetricSpansSpanIDMetricsMetricIDPatchRequestTypedDict(TypedDict):
    span_id: str
    r"""The id of the span"""
    metric_id: str
    r"""The id of the metric to update"""
    update_span_metric_request: UpdateSpanMetricRequestTypedDict


class UpdateMetricSpansSpanIDMetricsMetricIDPatchRequest(BaseModel):
    span_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The id of the span"""

    metric_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The id of the metric to update"""

    update_span_metric_request: Annotated[
        UpdateSpanMetricRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
