"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from opperai.types import BaseModel
from opperai.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class GetFunctionByNameFunctionsByNameNameGetRequestTypedDict(TypedDict):
    name: str
    r"""The name of the function to retrieve"""


class GetFunctionByNameFunctionsByNameNameGetRequest(BaseModel):
    name: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The name of the function to retrieve"""
