"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .app_api_public_v2_functions_callfunctionrequest import (
    AppAPIPublicV2FunctionsCallFunctionRequest,
    AppAPIPublicV2FunctionsCallFunctionRequestTypedDict,
)
from opperai.types import BaseModel
from opperai.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class CallFunctionRevisionFunctionsFunctionIDCallRevisionIDPostRequestTypedDict(
    TypedDict
):
    function_id: str
    r"""The id of the function to call"""
    revision_id: str
    r"""The id of the revision to call"""
    app_api_public_v2_functions_call_function_request: (
        AppAPIPublicV2FunctionsCallFunctionRequestTypedDict
    )


class CallFunctionRevisionFunctionsFunctionIDCallRevisionIDPostRequest(BaseModel):
    function_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The id of the function to call"""

    revision_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The id of the revision to call"""

    app_api_public_v2_functions_call_function_request: Annotated[
        AppAPIPublicV2FunctionsCallFunctionRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
