"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from opperai.types import BaseModel
from opperai.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class GetTraceTracesTraceIDGetRequestTypedDict(TypedDict):
    trace_id: str
    r"""The id of the trace to get"""


class GetTraceTracesTraceIDGetRequest(BaseModel):
    trace_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The id of the trace to get"""
