"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .updatecustommodelrequest import (
    UpdateCustomModelRequest,
    UpdateCustomModelRequestTypedDict,
)
from opperai.types import BaseModel
from opperai.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class UpdateCustomModelModelsCustomModelIDPatchRequestTypedDict(TypedDict):
    model_id: str
    r"""The ID of the custom language model to update"""
    update_custom_model_request: UpdateCustomModelRequestTypedDict


class UpdateCustomModelModelsCustomModelIDPatchRequest(BaseModel):
    model_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The ID of the custom language model to update"""

    update_custom_model_request: Annotated[
        UpdateCustomModelRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
