"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from opperai.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class Detail(str, Enum):
    AUTO = "auto"
    LOW = "low"
    HIGH = "high"


class ImageURLTypedDict(TypedDict):
    url: str
    detail: NotRequired[Detail]


class ImageURL(BaseModel):
    url: str

    detail: Optional[Detail] = None
