"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .openai_types_chat_chat_completion_message_tool_call_param_function import (
    OpenaiTypesChatChatCompletionMessageToolCallParamFunction,
    OpenaiTypesChatChatCompletionMessageToolCallParamFunctionTypedDict,
)
from opperai.types import BaseModel
from opperai.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal
from typing_extensions import Annotated, TypedDict


class ChatCompletionMessageToolCallParamTypedDict(TypedDict):
    id: str
    function: OpenaiTypesChatChatCompletionMessageToolCallParamFunctionTypedDict
    type: Literal["function"]


class ChatCompletionMessageToolCallParam(BaseModel):
    id: str

    function: OpenaiTypesChatChatCompletionMessageToolCallParamFunction

    TYPE: Annotated[
        Annotated[Literal["function"], AfterValidator(validate_const("function"))],
        pydantic.Field(alias="type"),
    ] = "function"
