"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .createdatasetentryrequest import (
    CreateDatasetEntryRequest,
    CreateDatasetEntryRequestTypedDict,
)
from opperai.types import BaseModel
from opperai.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class CreateDatasetEntryDatasetsDatasetIDPostRequestTypedDict(TypedDict):
    dataset_id: str
    r"""The id of the dataset"""
    create_dataset_entry_request: CreateDatasetEntryRequestTypedDict


class CreateDatasetEntryDatasetsDatasetIDPostRequest(BaseModel):
    dataset_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The id of the dataset"""

    create_dataset_entry_request: Annotated[
        CreateDatasetEntryRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
