"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from opperai.types import BaseModel
from opperai.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class QueryDatasetEntriesDatasetsDatasetIDEntriesQueryPostRequestTypedDict(TypedDict):
    dataset_id: str
    r"""The id of the dataset"""
    query: str
    r"""The query to search for"""
    limit: NotRequired[int]
    r"""The limit of the entries to get"""


class QueryDatasetEntriesDatasetsDatasetIDEntriesQueryPostRequest(BaseModel):
    dataset_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The id of the dataset"""

    query: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]
    r"""The query to search for"""

    limit: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 5
    r"""The limit of the entries to get"""
