"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from opperai.types import BaseModel
from typing_extensions import TypedDict


class CreateKnowledgeBaseResponseTypedDict(TypedDict):
    id: str
    name: str
    created_at: datetime
    embedding_model: str


class CreateKnowledgeBaseResponse(BaseModel):
    id: str

    name: str

    created_at: datetime

    embedding_model: str
