"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from opperai.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from opperai.utils import FieldMetadata, QueryParamMetadata
from pydantic import model_serializer
from typing_extensions import Annotated, NotRequired, TypedDict


class ListFunctionsFunctionsGetRequestTypedDict(TypedDict):
    name: NotRequired[Nullable[str]]
    r"""Filter functions by name"""
    sort: NotRequired[Nullable[str]]
    r"""Sort the functions by name or created_at, use '-' to sort in descending order"""
    offset: NotRequired[Nullable[int]]
    r"""The offset of the page of functions to return when paginating"""
    limit: NotRequired[Nullable[int]]
    r"""The number of functions to return per page when paginating"""


class ListFunctionsFunctionsGetRequest(BaseModel):
    name: Annotated[
        OptionalNullable[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Filter functions by name"""

    sort: Annotated[
        OptionalNullable[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Sort the functions by name or created_at, use '-' to sort in descending order"""

    offset: Annotated[
        OptionalNullable[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""The offset of the page of functions to return when paginating"""

    limit: Annotated[
        OptionalNullable[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""The number of functions to return per page when paginating"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["name", "sort", "offset", "limit"]
        nullable_fields = ["name", "sort", "offset", "limit"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
