"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from opperai.types import BaseModel
from typing import Any, Dict, Optional
from typing_extensions import NotRequired, TypedDict


class OpenaiTypesChatCompletionCreateParamsFunctionTypedDict(TypedDict):
    name: str
    description: NotRequired[str]
    parameters: NotRequired[Dict[str, Any]]


class OpenaiTypesChatCompletionCreateParamsFunction(BaseModel):
    name: str

    description: Optional[str] = None

    parameters: Optional[Dict[str, Any]] = None
