"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .updatefunctionrequest import UpdateFunctionRequest, UpdateFunctionRequestTypedDict
from opperai.types import BaseModel
from opperai.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class UpdateFunctionFunctionsFunctionIDPatchRequestTypedDict(TypedDict):
    function_id: str
    r"""Unique identifier of the function given as a UUID"""
    update_function_request: UpdateFunctionRequestTypedDict


class UpdateFunctionFunctionsFunctionIDPatchRequest(BaseModel):
    function_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Unique identifier of the function given as a UUID"""

    update_function_request: Annotated[
        UpdateFunctionRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
