"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from opperai.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class WebSearchOptionsUserLocationApproximateTypedDict(TypedDict):
    city: NotRequired[str]
    country: NotRequired[str]
    region: NotRequired[str]
    timezone: NotRequired[str]


class WebSearchOptionsUserLocationApproximate(BaseModel):
    city: Optional[str] = None

    country: Optional[str] = None

    region: Optional[str] = None

    timezone: Optional[str] = None
