"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from typing import TYPE_CHECKING
from importlib import import_module

if TYPE_CHECKING:
    from .apierror import APIError
    from .badrequesterror import BadRequestError, BadRequestErrorData
    from .conflicterror import ConflictError, ConflictErrorData
    from .error import Error, ErrorData
    from .notfounderror import NotFoundError, NotFoundErrorData
    from .requestvalidationerror import (
        RequestValidationError,
        RequestValidationErrorData,
    )
    from .unauthorizederror import UnauthorizedError, UnauthorizedErrorData

__all__ = [
    "APIError",
    "BadRequestError",
    "BadRequestErrorData",
    "ConflictError",
    "ConflictErrorData",
    "Error",
    "ErrorData",
    "NotFoundError",
    "NotFoundErrorData",
    "RequestValidationError",
    "RequestValidationErrorData",
    "UnauthorizedError",
    "UnauthorizedErrorData",
]

_dynamic_imports: dict[str, str] = {
    "APIError": ".apierror",
    "BadRequestError": ".badrequesterror",
    "BadRequestErrorData": ".badrequesterror",
    "ConflictError": ".conflicterror",
    "ConflictErrorData": ".conflicterror",
    "Error": ".error",
    "ErrorData": ".error",
    "NotFoundError": ".notfounderror",
    "NotFoundErrorData": ".notfounderror",
    "RequestValidationError": ".requestvalidationerror",
    "RequestValidationErrorData": ".requestvalidationerror",
    "UnauthorizedError": ".unauthorizederror",
    "UnauthorizedErrorData": ".unauthorizederror",
}


def __getattr__(attr_name: str) -> object:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(
            f"No {attr_name} found in _dynamic_imports for module name -> {__name__} "
        )

    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(
            f"Failed to import {attr_name} from {module_name}: {e}"
        ) from e
    except AttributeError as e:
        raise AttributeError(
            f"Failed to get {attr_name} from {module_name}: {e}"
        ) from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)
